@@ -67,13 +67,9 @@ test_that("mock db: check output format", {
   ) %in%
     names(attrition(inc))))
 
-  expect_equal(suppressWarnings(incidenceAttrition(inc)), attrition(inc))
-
   my_settings <- settings(inc)
   expect_true(nrow(my_settings) > 0)
 
-  expect_equal(settings(inc), suppressWarnings(incidenceSet(inc)))
-
   # do not return participants as default
   expect_true(is.null(participants(inc, 1)))
   CDMConnector::cdm_disconnect(cdm)
